@@ -61,12 +61,16 @@ FitResult CDL012Swaps::Fit()
             }
         }
 
-        if(!foundbetter) {result.Model = this; return result;}
+        if(!foundbetter)
+        {
+          //result.Model = this;
+          return result;
+        }
     }
 
 
     //std::cout<<"Did not achieve CW Swap min" << std::endl;
-    result.Model = this;
+    //result.Model = this;
     return result;
 }
 
