@@ -32,6 +32,7 @@ Rcpp::List L0LearnFit(const arma::mat& X, const arma::vec& y, const std::string
     P.MaxNumSwaps = MaxNumSwaps;
     P.ScreenSize = ScreenSize;
     P.NoSelectK = ExcludeFirstK;
+    P.intercept = Intercept;
     PG.P = P;
 
     if (Loss == "SquaredError") {PG.P.Specs.SquaredError = true;}
@@ -105,11 +106,13 @@ Rcpp::List L0LearnFit(const arma::mat& X, const arma::vec& y, const std::string
 
     }
     */
-    return Rcpp::List::create(Rcpp::Named(FirstParameter) = G.Lambda0,
+    Rcpp::List l = Rcpp::List::create(Rcpp::Named(FirstParameter) = G.Lambda0,
                               Rcpp::Named(SecondParameter) = G.Lambda12, // contains 0 in case of L0
                               Rcpp::Named("SuppSize") = G.NnzCount,
                               Rcpp::Named("beta") = Bs,
                               Rcpp::Named("a0") = G.Intercepts,
                               Rcpp::Named("Converged") = G.Converged);
 
+    return l;
+
 }
