@@ -9,7 +9,7 @@ struct FitResult
     arma::sp_mat B;
     CD * Model;
     unsigned int IterNum;
-    arma::vec r;
+    arma::vec * r;
     std::vector<double> ModelParams;
     double intercept = 0; // used by classification models
     arma::vec ExpyXB; // Used by logistic regression
